Name:           jacoco
Version:        0.8.8
Release:        %mkrel 2
Group:          Development/Java
Summary:        Java Code Coverage for Eclipse
License:        EPL-2.0
URL:            https://www.eclemma.org/jacoco/
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch
Source0:        https://github.com/jacoco/jacoco/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  git
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-dependency-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-shade-plugin)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-api)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.codehaus.mojo:buildnumber-maven-plugin)
BuildRequires:  mvn(org.codehaus.mojo:exec-maven-plugin)
BuildRequires:  mvn(org.ow2.asm:asm)
BuildRequires:  mvn(org.ow2.asm:asm-analysis)
BuildRequires:  mvn(org.ow2.asm:asm-commons)
BuildRequires:  mvn(org.ow2.asm:asm-tree)

# required by wrapper scripts
Requires:       javapackages-tools

%description
JaCoCo is a free code coverage library for Java, 
which has been created by the EclEmma team based on the lessons learned 
from using and integration existing libraries over the last five years. 

%package    maven-plugin
Summary:    A Jacoco plugin for maven
%description maven-plugin
A Jacoco plugin for maven.

%{?javadoc_package}

%prep

# -S: enable usage of git repo
# -p1: strip one level dir in patch(es)
%autosetup -S git -p1

# delete precompiled jar and class files
find -type f '(' -iname '*.jar' -o -iname '*.class' ')' -print -delete

# disable unnecessary modules
%pom_disable_module ../jacoco org.jacoco.build
%pom_disable_module ../org.jacoco.doc org.jacoco.build
%pom_disable_module ../org.jacoco.examples org.jacoco.build
%pom_disable_module ../org.jacoco.tests org.jacoco.build

# Remove unnecessary dependency on maven-javadoc-plugin
%pom_remove_plugin -r :maven-javadoc-plugin

# Remove enforcer plugin that causes build failure of 'Jacoco :: Maven Plugin'
%pom_remove_plugin -r :maven-enforcer-plugin

# Don't build jars with classifier ":nodeps:"
%pom_remove_plugin :maven-shade-plugin \
    org.jacoco.ant \
    org.jacoco.cli

# remove unnecessary plugin
%pom_remove_plugin -r :spotless-maven-plugin

# remove beanshell plugin
# later, we need to redefine various properties defined by it
%pom_remove_plugin :beanshell-maven-plugin \
    org.jacoco.build

# Remove "requires osgi(org.apache.ant)"
%pom_xpath_remove 'pom:configuration/pom:instructions/pom:Require-Bundle' \
    org.jacoco.ant

# Remove requires on maven-plugin-plugin:report
%pom_xpath_remove 'pom:execution[pom:id = "report"]' \
    jacoco-maven-plugin

# Define properties
%pom_xpath_inject 'pom:properties' '
    <unqualifiedVersion>${project.version}</unqualifiedVersion>
    <buildQualifier>${maven.build.timestamp}</buildQualifier>
    <qualified.bundle.version>${unqualifiedVersion}.${buildQualifier}</qualified.bundle.version>
    <jacoco.runtime.package.name>org.jacoco.agent.rt.internal_fedora</jacoco.runtime.package.name>' \
      org.jacoco.build

# install jacoco-maven-plugin package
%mvn_package ":jacoco-maven-plugin:{jar,pom}:{}:" maven-plugin

# install jacoco package
%mvn_package ":{org.}*:{jar,pom}:runtime:"

# don't install parent package
%mvn_package :root __noinstall
%mvn_package :org.jacoco.build __noinstall

%build
%mvn_build -f -- -Dmaven.compiler.release=8 -Dproject.build.sourceEncoding=UTF-8 -Dbuild.date=$(date +%Y/%m/%d)

%install
%mvn_install

# ant config
mkdir -p %{buildroot}%{_sysconfdir}/ant.d
echo %{name} %{name}/org.jacoco.ant objectweb-asm/asm > %{buildroot}%{_sysconfdir}/ant.d/%{name}

# wrapper script
%jpackage_script org.jacoco.cli.internal.Main "" "" jacoco/org.jacoco.cli:args4j:objectweb-asm:jacoco/org.jacoco.core:jacoco/org.jacoco.report jacococli true

%files -f .mfiles
%config(noreplace) %{_sysconfdir}/ant.d/%{name}
%doc README.md
%license LICENSE.md
%{_bindir}/jacococli

%files maven-plugin -f .mfiles-maven-plugin




%changelog
* Fri Jan 27 2023 daviddavid <daviddavid> 0.8.8-2.mga9
+ Revision: 1936441
- rebuild with fixed maven-reporting-api 3.1.1 and so remove no
  more needed Upgrade-maven-reporting-api-to-3.1.0 patch

* Fri Dec 09 2022 daviddavid <daviddavid> 0.8.8-1.mga9
+ Revision: 1919744
- New upstream release 0.8.8
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Sep 10 2020 daviddavid <daviddavid> 0.8.3-2.mga8
+ Revision: 1624254
- bumped to sources 0.8.3 which are aligned with currenlty shiped ojkectweb-asm
- aligned pugins with current fedora state
- org.apache.felix:maven-bundle-plugin should be returned, its absence is killing
  jdk11 exported packages generation
- the manual manifest is not an option
- Rebuilt for JDK-11
- Remove unnecessary dependency on maven-javadoc-plugin
- Use xmvn-javadoc unconditionally, fixing javadoc generation
- Add files for javadoc subpackage

* Wed Feb 12 2020 umeabot <umeabot> 0.7.8-3.mga8
+ Revision: 1501769
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 0.7.8-2.mga7
+ Revision: 1278893
- Mageia 7 Mass Rebuild

* Fri Aug 31 2018 daviddavid <daviddavid> 0.7.8-1.mga7
+ Revision: 1255843
- new version: 6.2 (sync with fc29)

* Wed May 17 2017 neoclust <neoclust> 0.7.7-1.mga6
+ Revision: 1102728
- New version 0.7.7

* Tue May 10 2016 daviddavid <daviddavid> 0.7.6-1.mga6
+ Revision: 1012186
- Update to upstream 0.7.6

* Wed Mar 02 2016 neoclust <neoclust> 0.7.5-4.mga6
+ Revision: 981833
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 0.7.5-3.mga6
+ Revision: 976545
- First rebuild of the java stack
- sync package jacoco with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Fri Dec 19 2014 pterjan <pterjan> 0.7.2-2.mga5
+ Revision: 804293
- Clean rebuild
- Sync with Fedora 21 (update to 0.7.2)
- Restore
+ sander85 <sander85>
- Depends on broken java stack
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.6.3-7.mga4
+ Revision: 535844
- Mageia 4 Mass Rebuild

* Sat Sep 21 2013 dmorgan <dmorgan> 0.6.3-6.mga4
+ Revision: 482664
- Rebuild against new javapackages
- Remove fest-assert BR
- Split maven package

* Fri Jul 05 2013 dmorgan <dmorgan> 0.6.0-3.mga4
+ Revision: 450294
- Java Stack Rebuild to fix Requires

* Sat Jan 12 2013 umeabot <umeabot> 0.6.0-2.mga3
+ Revision: 354669
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Dec 07 2012 dmorgan <dmorgan> 0.6.0-1.mga3
+ Revision: 327780
- imported package jacoco


* Wed Nov 21 2012 Alexander Kurtakov <akurtako@redhat.com> 0.6.0-1
- Update to upstream 0.6.0.

* Mon Sep 17 2012 Krzysztof Daniel <kdaniel@redhat.com> 0.5.9-2
- Add BR to fest-assert.

* Tue Sep 11 2012 Krzysztof Daniel <kdaniel@redhat.com> 0.5.9-1
- Update to upstream 0.5.10 release.

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.7-0.6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue May 8 2012 Krzysztof Daniel <kdaniel@redhat.com> 0.5.7-0.5
- Dropped dependency version to maven-shade-plugin.

* Tue May 8 2012 Krzysztof Daniel <kdaniel@redhat.com> 0.5.7-0.4
- Fixed rpmlint warnings.

* Tue May 8 2012 Krzysztof Daniel <kdaniel@redhat.com> 0.5.7-0.3
- Removed symlink to java.

* Tue May 8 2012 Krzysztof Daniel <kdaniel@redhat.com> 0.5.7-0.2
- Restructured packages
- Generated javadoc as set of plain files.

* Thu May 3 2012 Krzysztof Daniel <kdaniel@redhat.com> 0.5.7-0.1
- Initial release.
